# Changelog

## [Unreleased](https://github.com/architdatar/ml_uncertainty/tree/HEAD)

**Merged pull requests:**

- Dev [\#3](https://github.com/architdatar/ml_uncertainty/pull/3)

## [v1.0.0](https://github.com/architdatar/ml_uncertainty/tree/v1.0.0) (2025-01-16)

## [dev](https://github.com/architdatar/ml_uncertainty/tree/dev) (2024-10-29)

**Merged pull requests:**

- Added tests and removed support for Python 3.12 [\#2](https://github.com/architdatar/ml_uncertainty/pull/2)
- Merging from  branch github for first release [\#1](https://github.com/architdatar/ml_uncertainty/pull/1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
